#

##

##

##

###

###

###

##

##

    	shares

    	docker
    		docker network create --subnet=192.168.0.0/24 container_network
    		docker run --network container_network --ip 192.168.0.151 -v .:/shares -it jumps:v2.1.0
    		docker exec -it 389597d6510a bash

    	link the readme
    		ln -s venues/stages/shares/room.md readme.MD

    	poetry
    		pip install poetry poetry-plugin-export

    		add
    			poetry add sanic

    			#
    			#	if dev dependencies
    			#
    			# poetry export --with dev --format requirements.txt --output requirements.txt

    			rm -rf /shares/venues/stages_pip && poetry export --format requirements.txt --output requirements.txt && pip install -r requirements.txt -t /shares/venues/stages_pip

    			# /root/.cache/pypoetry/virtualenvs/shares-p2eJTVsK-py3.10/lib/python3.10/site-packages/
    			# cp -R /root/.cache/pypoetry/virtualenvs/shares-p2eJTVsK-py3.10/lib/python3.10/site-packages/ /shares/venues/stages_pip

    		upgrade
    			poetry update sanic

    		installations venv
    			poetry config virtualenvs.path /path/to/your/directory
    			poetry env use python3
    			poetry shell

    	publishing

    		#
    		#	statuses
    		#
    		python3 /shares/venues/stages/shares/_status/status.proc.py
    		python3 /shares/status_E2E/status.proc.py

    		#
    		#	git push
    		#
    		#		if Circle CI is successful, then publish
    		#

    		#
    		#	increase version
    		#

    		#
    		#	poetry auth
    		#
    		rm -rf dist && poetry build --verbose && poetry publish --verbose;

    	important
    		poetry show --tree